import torch
import torchvision
import numpy as np
from torchsummary import summary

from make_model import make_model


#############

vocab = "<ABCDEFGHKLMNPQRSTUVXYZ0123456789#>"
# start symbol <
# end symbol >
token2char = {0: "PAD"}
for i, c in enumerate(vocab):
    token2char[i+1] = c

#############

model = make_model(len(token2char)).cuda()

pretrained_weight_path = 'checkpoint_113.pt'  
pretrained_dict = torch.load(pretrained_weight_path)
model.load_state_dict(pretrained_dict, strict=False)


input_names = [ "input" ]  
output_names = [ "ys", "probs"]

x = torch.randn(1, 3, 128, 256, dtype=torch.float32, requires_grad=True).cuda()
onnx_file_name = "ocr_3-128-256-dynamic.onnx"
dynamic_axes = {"input": {0: "batch_size"}, "ys": {0: "batch_size"}, "probs": {0: "batch_size"}}

print("Exporting ONNX model ...")

torch.onnx.export(model, 
                  x,
                  onnx_file_name, 
                  export_params=True,
                  do_constant_folding=True,
                  opset_version=10,
                  input_names=input_names,
                  output_names=output_names,
                  dynamic_axes=dynamic_axes
                 )

print("Done!")

